let currentSpaceId = null;
const spaces = [];
const tasks = {};

document.addEventListener('DOMContentLoaded', () => {
  setupEventListeners();
  loadSpaces();
});

function setupEventListeners() {
  document.getElementById('space-form').addEventListener('submit', handleNewSpace);
  document.getElementById('task-form').addEventListener('submit', handleNewTask);
  document.querySelector('.menu-toggle').addEventListener('click', toggleMenu);
}

function toggleMenu() {
  document.querySelector('.nav-links').classList.toggle('active');
}

function handleNewSpace(e) {
  e.preventDefault();
  const title = document.getElementById('space-title').value;
  const description = document.getElementById('space-description').value;
  const tag = document.getElementById('space-tag').value;

  const space = {
    id: Date.now(),
    title,
    description,
    tag
  };

  spaces.push(space);
  tasks[space.id] = [];
  
  e.target.reset();
  renderSpaces();
}

function handleNewTask(e) {
  e.preventDefault();
  if (!currentSpaceId) return;

  const title = document.getElementById('task-title').value;
  const description = document.getElementById('task-description').value;
  const tag = document.getElementById('task-tag').value;

  const task = {
    id: Date.now(),
    title,
    description,
    tag,
    spaceId: currentSpaceId
  };

  tasks[currentSpaceId].push(task);
  e.target.reset();
  renderTasks();
}

function renderSpaces() {
  const container = document.getElementById('spaces-container');
  container.innerHTML = spaces.map(space => `
    <div class="space-card" onclick="showSpaceDetail(${space.id})">
      <span class="space-tag">${space.tag}</span>
      <h3>${space.title}</h3>
      <p>${space.description}</p>
    </div>
  `).join('');
}

function showSpaceDetail(spaceId) {
  currentSpaceId = spaceId;
  const space = spaces.find(s => s.id === spaceId);
  
  document.getElementById('spaces-list').classList.add('hidden');
  document.getElementById('new-space').classList.add('hidden');
  document.getElementById('space-detail').classList.remove('hidden');
  
  document.getElementById('space-header').innerHTML = `
    <h2>${space.title}</h2>
    <p>${space.description}</p>
    <span class="space-tag">${space.tag}</span>
  `;
  
  renderTasks();
}

function renderTasks() {
  const container = document.getElementById('tasks-list');
  const spaceTasks = tasks[currentSpaceId] || [];
  
  container.innerHTML = `
    <h3>Tasks</h3>
    ${spaceTasks.map(task => `
      <div class="space-card">
        <span class="space-tag">${task.tag}</span>
        <h4>${task.title}</h4>
        <p>${task.description}</p>
      </div>
    `).join('')}
  `;
}

function loadSpaces() {
  // This would normally load from an API or localStorage
  renderSpaces();
}
